==> haskell-chell-quickcheck-0.2.5.4-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-chell-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 chell-quickcheck
version:              0.2.5.4
visibility:           public
id:                   chell-quickcheck-0.2.5.4-IKyPl7SYIuGGvg93iTrHbT
key:                  chell-quickcheck-0.2.5.4-IKyPl7SYIuGGvg93iTrHbT
license:              MIT
maintainer:           Chris Martin, Julie Moronuki
author:               John Millikin <john@john-millikin.com>
homepage:             https://github.com/typeclasses/chell
synopsis:             QuickCheck support for Chell
description:          QuickCheck support for the Chell testing library.
category:             Testing
abi:                  4a1fa0bd1aed9140d2d0d5ff68a718ed
exposed:              True
exposed-modules:      Test.Chell.QuickCheck
import-dirs:          /usr/lib/ghc-9.4.8/site-local/chell-quickcheck-0.2.5.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/chell-quickcheck-0.2.5.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/chell-quickcheck-0.2.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chell-quickcheck
hs-libraries:         HSchell-quickcheck-0.2.5.4-IKyPl7SYIuGGvg93iTrHbT
depends:
    QuickCheck-2.14.3-JggVBRSlKYhHS3I1VorUGb base-4.17.2.1
    chell-0.5.0.2-156DnEnuie5KnbKAPDcxaD
    random-1.2.1.2-J6mYBSGGDLVAHQqGKIioSR

haddock-interfaces:
    /usr/share/doc/haskell-chell-quickcheck/html/chell-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-chell-quickcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chell-quickcheck-0.2.5.4-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-chell-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 chell-quickcheck
version:              0.2.5.4
visibility:           public
id:                   chell-quickcheck-0.2.5.4-DXC47oBzeukC9wHujYEH7T
key:                  chell-quickcheck-0.2.5.4-DXC47oBzeukC9wHujYEH7T
license:              MIT
maintainer:           Chris Martin, Julie Moronuki
author:               John Millikin <john@john-millikin.com>
homepage:             https://github.com/typeclasses/chell
synopsis:             QuickCheck support for Chell
description:          QuickCheck support for the Chell testing library.
category:             Testing
abi:                  6770664936d2d67dcd676980cbecbb0a
exposed:              True
exposed-modules:      Test.Chell.QuickCheck
import-dirs:          /usr/lib/ghc-9.4.8/site-local/chell-quickcheck-0.2.5.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/chell-quickcheck-0.2.5.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/chell-quickcheck-0.2.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chell-quickcheck
hs-libraries:         HSchell-quickcheck-0.2.5.4-DXC47oBzeukC9wHujYEH7T
depends:
    QuickCheck-2.14.3-DOFi1GQ9eE04hBoMxr6sJJ base-4.17.2.1
    chell-0.5.0.2-G7pOhC2k0VE4gijvY0BeGh
    random-1.2.1.2-LUVepo9xpbYCdyIKOUBgF2

haddock-interfaces:
    /usr/share/doc/haskell-chell-quickcheck/html/chell-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-chell-quickcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
